@@ -16,7 +16,7 @@
 import adonthell
 import events
 
-class lft_to_vnd:
+class lft_to_vnd(object):
 
     # Parameters:
     # smdest: destination submap
