@@ -16,7 +16,7 @@
 import adonthell
 import events
 
-class vnd_to_lft:
+class vnd_to_lft(object):
     # Parameters:
     # smdest: destination submap
     # xdest: X position on smdest
