@@ -15,7 +15,7 @@
 
 import adonthell
 
-class center_character:
+class center_character(object):
 
     # Parameters:
     # mapcharinstance: Name of the mapcharacter to follow
